---
icon: material/information-slab-circle
---

# :material-information-slab-circle: Introduction

## Description

**EasyUtilities** is a scientific software for sharing utilities,
including reusable classes and functions, to be used across EasyScience
modules.

**EasyUtilities** is developed as a Python library.

**EasyUtilities** is developed using the
[EasyScience framework](https://easyscience.org).

## License

**EasyUtilities** library is released under the
[BSD 3-Clause License](https://raw.githubusercontent.com/easyscience/utils/master/LICENSE).

## Releases

The latest version of the **EasyUtilities** library is
[{{ vars.release_version }}](https://github.com/easyscience/utils/releases/latest).

For a complete list of new features, bug fixes, and improvements, see
the
[GitHub Releases page](https://github.com/easyscience/utils/releases).

## Citation

If you use **EasyUtilities** library in your work, please cite the
specific version you used.

All official releases of the **EasyUtilities** library are archived on
Zenodo, each with a version-specific Digital Object Identifier (DOI).

Citation details in various styles (e.g., APA, MLA) and formats (e.g.,
BibTeX, JSON) are available on the
[Zenodo archive page](https://doi.org/10.5281/zenodo.18163581).

## Contributing

We welcome contributions from the community! **EasyUtilities** is
intended to be a community-driven, open-source project supported by a
diverse group of contributors.

The project is maintained by the
[European Spallation Source (ESS)](https://ess.eu).

To contribute, see our
[:material-account-plus: Contributing Guidelines](https://github.com/easyscience/utils/blob/master/CONTRIBUTING.md)
on GitHub.

## Get in Touch

For general questions or feedback, contact us at
[support@easyscience.org](mailto:support@easyscience.org).

To report bugs or request features, please use the
[GitHub Issue Tracker](https://github.com/easyscience/utils/issues)
(free registration required).
